require 'spec_helper'
require 'stringio'

describe Evrone::CI::Message do

  %w{ PerformBuild PerformJob BuildLog JobLog BuildStatus JobStatus }.each do |klass|

    context "#{klass}" do

      let(:inst) { described_class.const_get klass }
      subject { inst.test_message }

      it "should be valid" do
        expect(subject.validate!).to be_true
      end

      it "should be successfuly serialized/deserialized" do
        io = StringIO.new
        subject.serialize(io)
        io.rewind
        obj = described_class.const_get(klass).parse(io)
        expect(obj.validate!).to be_true
      end

      it "should serialize via to_serialized_string" do
        io = StringIO.new
        subject.serialize(io)
        io.rewind

        expect(subject.to_serialized_string).to eq io.read
      end

      if %w{ PerformBuild PerformJob }.include?(klass)
        context "with pull reqest" do
          subject { inst.test_pull_request_message }

          it "should be valid" do
            expect(subject.validate!).to be_true
          end

          it "should have pull_request_id" do
            expect(subject.pull_request_id).to be
          end
        end
      end

      if klass == 'JobStatus'
        it "should have matrix" do
          expect(subject.matrix).to eq ["env:FOO = 1", "rvm:1.9.3"]
        end
      end

    end
  end
end
